@@ -1,9 +1,10 @@
 import json
 from copy import deepcopy
 from getpass import getpass
+from typing import Optional
 
 from ..context import Context
-from ..executor import Executor
+from ..executor import Executor, render_script_with_tmp_root
 from ..op_template import PythonScriptOPTemplate, ShellOPTemplate
 from ..utils import randstr
 from ..workflow import Workflow
@@ -22,8 +23,8 @@ class LebesgueExecutor(Executor):
 
     def __init__(
             self,
-            executor: str = None,
-            extra: dict = None,
+            executor: Optional[str] = None,
+            extra: Optional[dict] = None,
     ) -> None:
         self.executor = executor
         self.extra = extra
@@ -42,8 +43,8 @@ class LebesgueExecutor(Executor):
                 self.extra) if isinstance(self.extra, dict) else self.extra
         if self.executor == "lebesgue_v2" and template.annotations[
                 "workflow.dp.tech/executor"] != "lebesgue_v2":
-            new_template.script = new_template.script.replace(
-                "/tmp", "$(pwd)/tmp")
+            new_template.script = render_script_with_tmp_root(template,
+                                                              "$(pwd)/tmp")
             if isinstance(template, ShellOPTemplate):
                 new_template.script = "mkdir -p tmp\n" + new_template.script
             if isinstance(template, PythonScriptOPTemplate):
@@ -71,17 +72,17 @@ class LebesgueContext(Context):
 
     def __init__(
             self,
-            username: str = None,
-            password: str = None,
+            username: Optional[str] = None,
+            password: Optional[str] = None,
             bohrium_url: str = "https://bohrium.dp.tech",
             login_url: str = "https://workflow.dp.tech/account_gw/login",
-            app_name: str = None,
-            org_id: str = None,
-            user_id: str = None,
-            tag: str = None,
-            executor: str = None,
-            extra: dict = None,
-            authorization: str = None,
+            app_name: Optional[str] = None,
+            org_id: Optional[str] = None,
+            user_id: Optional[str] = None,
+            tag: Optional[str] = None,
+            executor: Optional[str] = None,
+            extra: Optional[dict] = None,
+            authorization: Optional[str] = None,
     ) -> None:
         self.bohrium_url = bohrium_url
         self.login_url = login_url
@@ -141,8 +142,8 @@ class LebesgueContext(Context):
             new_template.annotations["workflow.dp.tech/executor"] = \
                 self.executor
             if self.executor == "lebesgue_v2":
-                new_template.script = new_template.script.replace(
-                    "/tmp", "$(pwd)/tmp")
+                new_template.script = render_script_with_tmp_root(template,
+                                                                  "$(pwd)/tmp")
                 if isinstance(template, ShellOPTemplate):
                     new_template.script = "mkdir -p tmp\n" + \
                         new_template.script
