@@ -9,19 +9,31 @@ import jsonpickle
 from ..config import config
 from ..utils import (assemble_path_list, convert_dflow_list, copy_file,
                      remove_empty_dir_tag)
-from .opio import BigParameter, Parameter
+from .opio import Artifact, BigParameter, Parameter
 
 
 def handle_input_artifact(name, sign, slices=None, data_root="/tmp",
-                          sub_path=None):
-    if sub_path is None:
-        art_path = '%s/inputs/artifacts/%s' % (data_root, name)
+                          sub_path=None, n_parts=None):
+    if n_parts is not None:
+        path_list = []
+        for i in range(n_parts):
+            art_path = '%s/inputs/artifacts/dflow_%s_%s' % (data_root, name, i)
+            remove_empty_dir_tag(art_path)
+            pl = assemble_path_list(art_path)
+            if pl:
+                path_list += pl
+            else:
+                path_list.append(art_path)
     else:
-        art_path = '%s/inputs/artifacts/%s/%s' % (data_root, name, sub_path)
-    if not os.path.exists(art_path):  # for optional artifact
-        return None
-    remove_empty_dir_tag(art_path)
-    path_list = assemble_path_list(art_path)
+        if sub_path is None:
+            art_path = '%s/inputs/artifacts/%s' % (data_root, name)
+        else:
+            art_path = '%s/inputs/artifacts/%s/%s' % (data_root, name,
+                                                      sub_path)
+        if not os.path.exists(art_path):  # for optional artifact
+            return None
+        remove_empty_dir_tag(art_path)
+        path_list = assemble_path_list(art_path)
     if slices is not None:
         slices = slices if isinstance(slices, list) else [slices]
         path_list = [path_list[i] for i in slices]
@@ -122,7 +134,7 @@ def handle_output_artifact(name, value, sign, slices=None, data_root="/tmp"):
                     path, name, s, data_root))
 
     os.makedirs(data_root + "/outputs/artifacts/%s/%s" % (name, config[
-            "catalog_dir_name"]), exist_ok=True)
+        "catalog_dir_name"]), exist_ok=True)
     with open(data_root + "/outputs/artifacts/%s/%s/%s" % (name, config[
             "catalog_dir_name"], uuid.uuid4()), "w") as f:
         f.write(jsonpickle.dumps({"path_list": path_list}))
@@ -200,3 +212,21 @@ def handle_empty_dir(path):
         if len(ds) == 0 and len(fs) == 0:
             with open(os.path.join(dn, ".empty_dir"), "w"):
                 pass
+
+
+def handle_lineage(wf_name, pod_name, op_obj, input_urns, workflow_urn,
+                   data_root="/tmp"):
+    task_name = wf_name + "/" + pod_name
+    output_sign = op_obj.get_output_sign()
+    output_uris = {}
+    for name, sign in output_sign.items():
+        if isinstance(sign, Artifact):
+            output_uris[name] = op_obj.get_output_artifact_storage_key(name)
+    input_urns = {name: jsonpickle.loads(urn) if urn[:1] == "["
+                  else urn for name, urn in input_urns.items()}
+    output_urns = config["lineage"].register_task(
+        task_name, input_urns, output_uris, workflow_urn)
+    for name, urn in output_urns.items():
+        with open("%s/outputs/parameters/dflow_%s_urn" % (data_root, name),
+                  "w") as f:
+            f.write(urn)
